@@ -27,7 +27,7 @@ from invenio_records_resources.resources.records.resource import (
     request_search_args,
     request_view_args,
 )
-from invenio_records_resources.resources.records.utils import es_preference
+from invenio_records_resources.resources.records.utils import search_preference
 
 from .errors import RedirectException
 
@@ -97,7 +97,7 @@ class RecordResource(RecordResourceBase):
         hits = self.service.search_drafts(
             identity=g.identity,
             params=resource_requestctx.args,
-            es_preference=es_preference(),
+            search_preference=search_preference(),
             expand=resource_requestctx.args.get("expand", False),
         )
         return hits.to_dict(), 200
@@ -115,7 +115,7 @@ class RecordResource(RecordResourceBase):
             g.identity,
             resource_requestctx.view_args["pid_value"],
             params=resource_requestctx.args,
-            es_preference=es_preference(),
+            search_preference=search_preference(),
             expand=resource_requestctx.args.get("expand", False),
         )
         return hits.to_dict(), 200
