@@ -18,10 +18,7 @@ from mock_module.api import Draft
 @pytest.fixture()
 def example_draft(db, input_data, location):
     """Example draft."""
-    draft = Draft.create(
-        input_data,
-        expires_at=datetime(2020, 9, 7, 0, 0)
-    )
+    draft = Draft.create(input_data, expires_at=datetime(2020, 9, 7, 0, 0))
     draft.commit()
     db.session.commit()
     return draft
@@ -31,5 +28,5 @@ def example_draft(db, input_data, location):
 def indexer():
     """Indexer instance with correct Record class."""
     return RecordIndexer(
-        record_cls=Draft, record_to_index=lambda r: (r.index._name, '_doc')
+        record_cls=Draft, record_to_index=lambda r: (r.index._name, "_doc")
     )
